@@ -50,15 +50,17 @@ class Module:
         methods = self.specification["methods"]
         method = [meth for meth in methods if meth["name"] == method][0]
         Validator().validate_method_args(method, kwargs)
+        method_args = Validator().set_default_method_args(method, kwargs)
       except IndexError as err:
         raise LaboroError(f"UnknownMethodError: Unknown method: {method}") from err
-      self.context.put(func.__name__, func(self, **kwargs))
+      self.context.put(func.__name__, func(self, **method_args))
       return self.context.get(func.__name__)
     return wrapper
 
   def __enter__(self):
     self.specification = self._validate_spec()
     self._validate_args()
+    self._default_args()
     return self
 
   def __exit__(self, kind, value, traceback):
@@ -85,6 +87,12 @@ class Module:
       Validator().validate_obj_args(specification=spec_file,
                                     args=self.args)
 
+  def _default_args(self):
+    spec_file = os.path.join(os.path.dirname(self.filepath),
+                             "schema",
+                             "specification.yml")
+    self.args = Validator().set_default_obj_args(spec_file, self.args)
+
   def get_arg_value(self, arg):
     """Get the value of the specified argument.
 
